window.Gleam.initSearch([{"doc":"openfeature","title":"openfeature","content":"# OpenFeature Gleam SDK\n\n[![Package Version](https://img.shields.io/hexpm/v/openfeature)](https://hex.pm/packages/openfeature)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/openfeature/)\n\n[OpenFeature](https://openfeature.dev) is an open specification that provides a vendor-agnostic, community-driven API for feature flagging that works with your favorite feature flag management tool.\n\nThis repository contains the unofficial SDK implementation of the [specification](https://openfeature.dev/specification/) for the [Gleam](https://gleam.run/) programming language.\n\n## 🚀 Quick start\n\n### Requirements\n\n- Gleam [1+](https://github.com/gleam-lang/gleam/releases/tag/v1.0.0)\n\n### Install\n\n```sh\ngleam add openfeature\n```\n\n### Usage\n\n```gleam\nimport gleam/bool\nimport gleam/dict\nimport gleam/dynamic\nimport gleam/io\nimport gleam/option.{None}\nimport openfeature/api as openfeature\nimport openfeature/client\nimport openfeature/evaluation.{type ResolutionDetails}\nimport openfeature/evaluation_context\nimport openfeature/providers/in_memory\n\npub fn main() {\n  // flags defined in memory\n  let v2_flag =\n    in_memory.Flag(\n      default_variant: &quot;off&quot;,\n      variants: dict.from_list([\n        #(&quot;off&quot;, dynamic.from(False)),\n        #(&quot;on&quot;, dynamic.from(True)),\n      ]),\n      context_evaluator: None,\n    )\n  let flags = dict.from_list([#(&quot;v2_enabled&quot;, v2_flag)])\n\n  // configure a provider\n  let _ = openfeature.set_provider(in_memory.provider(flags))\n\n  // get a bool flag value\n  let flag_value =\n    openfeature.get_client()\n    |&gt; client.get_bool_value(&quot;v2_enabled&quot;, False, evaluation_context.empty())\n\n  // use the returned flag value\n  io.println(&quot;`v2_enabled` evaluated to: &quot; &lt;&gt; bool.to_string(flag_value))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/openfeature&gt;.\n\n## 🌟 Features\n\n| Status | Features                        | Description                                                                                                                        |\n| ------ | ------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- |\n| ✅      | [Providers](#providers)         | Integrate with a commercial, open source, or in-house feature management tool.                                                     |\n| ✅      | [Targeting](#targeting)         | Contextually-aware flag evaluation using [evaluation context](https://openfeature.dev/docs/reference/concepts/evaluation-context). |\n| ❌      | [Hooks](#hooks)                 | Add functionality to various stages of the flag evaluation life-cycle.                                                             |\n| ❌      | [Logging](#logging)             | Integrate with popular logging packages.                                                                                           |\n| ✅      | [Domains](#domains)             | Logically bind clients with providers.                                                                                             |\n| ❌      | [Eventing](#eventing)           | React to state changes in the provider or flag management system.                                                                  |\n| ✅      | [Shutdown](#shutdown)           | Gracefully clean up a provider during application shutdown.                                                                        |\n| ⚠️      | [Extending](#extending)         | Extend OpenFeature with custom providers and hooks.                                                                                |\n\n&lt;sub&gt;Implemented: ✅ | In-progress: ⚠️ | Not implemented yet: ❌&lt;/sub&gt;\n\n### Providers\n\n[Providers](https://openfeature.dev/docs/reference/concepts/provider) are an abstraction between a flag management system and the OpenFeature SDK. Look [here](https://openfeature.dev/ecosystem?instant_search%5BrefinementList%5D%5Btype%5D%5B0%5D=Provider&amp;instant_search%5BrefinementList%5D%5Btechnology%5D%5B0%5D=Gleam) for a complete list of available providers. If the provider you&#39;re looking for hasn&#39;t been created yet, see the [develop a provider](#develop-a-provider) section to learn how to build it yourself.\n\nOnce you&#39;ve added a provider as a dependency, it can be registered with OpenFeature like this:\n\n```gleam\nimport openfeature/api as openfeature\n\nopenfeature.set_provider(my_provider())\n```\n\nIn some situations, it may be beneficial to register multiple providers in the same application. This is possible using [domains](#domains), which is covered in more details below.\n\n### Targeting\n\nSometimes, the value of a flag must consider some dynamic criteria about the application or user, such as the user&#39;s location, IP, email address, or the server&#39;s location. In OpenFeature, we refer to this as [targeting](https://openfeature.dev/specification/glossary#targeting). If the flag management system you&#39;re using supports targeting, you can provide the input data using the [evaluation context](https://openfeature.dev/docs/reference/concepts/evaluation-context).\n\n```gleam\nimport gleam/dynamic\nimport gleam/option.{None}\nimport openfeature/api as openfeature\nimport openfeature/client\nimport openfeature/evaluation_context.{EvaluationContext}\n\n// set the global evaluation context\nopenfeature.set_context(\n  evaluation_context.targetless([\n    #(&quot;region&quot;, dynamic.from(&quot;us-east-1-iah-1a&quot;)),\n  ])\n)\n\n// set the client evaluation context\nlet my_app_client =\n  openfeature.get_domain_client(&quot;my-app&quot;)\n  |&gt; client.set_context(\n    evaluation_context.targetless([\n      #(&quot;version&quot;,  dynamic.from(&quot;1.4.6&quot;)),\n    ])\n  )\n\n// set the invocation context\nclient.resolve_bool_evaluation(\n  my_app_client,\n  &quot;bool-flag&quot;,\n  False,\n  evaluation_context.targeted(\n    &quot;userId:1234&quot;,\n    [#(&quot;company&quot;, dynamic.from(&quot;Wise&quot;))]\n  ),\n)\n```\n\n### Hooks\n\nTODO\n\n### Logging\n\nTODO\n\n### Domains\n\nClients can be assigned to a domain. A domain is a logical identifier which can be used to associate clients with a particular provider. If a domain has no associated provider, the default provider is used.\n\n```gleam\nimport openfeature/api as openfeature\n\n// registering the default provider\nopenfeature.set_provider(local_provider())\n// registering a domain provider\nopenfeature.set_domain_provider(&quot;cached-domain&quot;, cached_provider())\n\n// a client bound to the default provider\nopenfeature.get_client()\n// a client bound to the cached provider\nopenfeature.get_domain_client(&quot;cached-domain&quot;)\n```\n\n### Eventing\n\nTODO\n\n### Shutdown\n\nThe OpenFeature API provides a close function to perform a cleanup of all registered providers. This should only be called when your application is in the process of shutting down.\n\n```gleam\nimport openfeature/api as openfeature\n\nopenfeature.shutdown()\n```\n\n## Extending\n\n### Develop a provider\n\nTODO\n\n### Develop a hook\n\nTODO\n","url":"index.html"},{"doc":"openfeature/domain","title":"Domain","content":"pub type Domain {\n  Global\n  Scoped(scope: String)\n}\n\nGlobal\n\n\nScoped(scope: String)\n\n\nSynonyms:\nopenfeature/domain.Domain\nopenfeature/domain Domain","url":"openfeature/domain.html#Domain"},{"doc":"openfeature/domain","title":"openfeature/domain","content":"","url":"openfeature/domain.html"},{"doc":"openfeature/evaluation_context","title":"EvaluationContext","content":"pub type EvaluationContext {\n  EvaluationContext(\n    targeting_key: Option(String),\n    attributes: Dict(String, Dynamic),\n  )\n}\n\nEvaluationContext(\n  targeting_key: Option(String),\n  attributes: Dict(String, Dynamic),\n)\n\n\nSynonyms:\nopenfeature/evaluation_context.EvaluationContext\nopenfeature/evaluation_context EvaluationContext","url":"openfeature/evaluation_context.html#EvaluationContext"},{"doc":"openfeature/evaluation_context","title":"empty","content":"pub fn empty() -&gt; EvaluationContext\n\nSynonyms:\nopenfeature/evaluation_context.empty\nopenfeature/evaluation_context empty","url":"openfeature/evaluation_context.html#empty"},{"doc":"openfeature/evaluation_context","title":"get_all_attributes","content":"pub fn get_all_attributes(\n  evaluation_context: EvaluationContext,\n) -&gt; List(#(String, Dynamic))\n\nSynonyms:\nopenfeature/evaluation_context.get_all_attributes\nopenfeature/evaluation_context get_all_attributes","url":"openfeature/evaluation_context.html#get_all_attributes"},{"doc":"openfeature/evaluation_context","title":"get_attribute","content":"pub fn get_attribute(\n  evaluation_context: EvaluationContext,\n  key: String,\n) -&gt; Result(Dynamic, Nil)\n\nSynonyms:\nopenfeature/evaluation_context.get_attribute\nopenfeature/evaluation_context get_attribute","url":"openfeature/evaluation_context.html#get_attribute"},{"doc":"openfeature/evaluation_context","title":"merge","content":"pub fn merge(\n  initial_context: EvaluationContext,\n  overriding_context: EvaluationContext,\n) -&gt; EvaluationContext\n\nSynonyms:\nopenfeature/evaluation_context.merge\nopenfeature/evaluation_context merge","url":"openfeature/evaluation_context.html#merge"},{"doc":"openfeature/evaluation_context","title":"targeted","content":"pub fn targeted(\n  targeting_key: String,\n  attributes: List(#(String, Dynamic)),\n) -&gt; EvaluationContext\n\nSynonyms:\nopenfeature/evaluation_context.targeted\nopenfeature/evaluation_context targeted","url":"openfeature/evaluation_context.html#targeted"},{"doc":"openfeature/evaluation_context","title":"targetless","content":"pub fn targetless(\n  attributes: List(#(String, Dynamic)),\n) -&gt; EvaluationContext\n\nSynonyms:\nopenfeature/evaluation_context.targetless\nopenfeature/evaluation_context targetless","url":"openfeature/evaluation_context.html#targetless"},{"doc":"openfeature/evaluation_context","title":"openfeature/evaluation_context","content":"","url":"openfeature/evaluation_context.html"},{"doc":"openfeature/evaluation","title":"BoolEvaluation","content":"pub type BoolEvaluation =\n  GenericEvaluation(Bool)\n\n\nSynonyms:\nopenfeature/evaluation.BoolEvaluation\nopenfeature/evaluation BoolEvaluation","url":"openfeature/evaluation.html#BoolEvaluation"},{"doc":"openfeature/evaluation","title":"DynamicEvaluation","content":"pub type DynamicEvaluation =\n  GenericEvaluation(Dynamic)\n\n\nSynonyms:\nopenfeature/evaluation.DynamicEvaluation\nopenfeature/evaluation DynamicEvaluation","url":"openfeature/evaluation.html#DynamicEvaluation"},{"doc":"openfeature/evaluation","title":"ErrorCode","content":"pub type ErrorCode {\n  ProviderNotReady\n  FlagNotFound\n  ParseError\n  TypeMismatch\n  TargetingKeyMissing\n  InvalidContext\n  General\n}\n\nProviderNotReady\n\n\nFlagNotFound\n\n\nParseError\n\n\nTypeMismatch\n\n\nTargetingKeyMissing\n\n\nInvalidContext\n\n\nGeneral\n\n\nSynonyms:\nopenfeature/evaluation.ErrorCode\nopenfeature/evaluation ErrorCode","url":"openfeature/evaluation.html#ErrorCode"},{"doc":"openfeature/evaluation","title":"FloatEvaluation","content":"pub type FloatEvaluation =\n  GenericEvaluation(Float)\n\n\nSynonyms:\nopenfeature/evaluation.FloatEvaluation\nopenfeature/evaluation FloatEvaluation","url":"openfeature/evaluation.html#FloatEvaluation"},{"doc":"openfeature/evaluation","title":"IntEvaluation","content":"pub type IntEvaluation =\n  GenericEvaluation(Int)\n\n\nSynonyms:\nopenfeature/evaluation.IntEvaluation\nopenfeature/evaluation IntEvaluation","url":"openfeature/evaluation.html#IntEvaluation"},{"doc":"openfeature/evaluation","title":"Reason","content":"pub type Reason {\n  Disabled\n  Split\n  TargetingMatch\n  Default\n  Unknown\n  Cached\n  Static\n  Error\n}\n\nDisabled\n\n\nSplit\n\n\nTargetingMatch\n\n\nDefault\n\n\nUnknown\n\n\nCached\n\n\nStatic\n\n\nError\n\n\nSynonyms:\nopenfeature/evaluation.Reason\nopenfeature/evaluation Reason","url":"openfeature/evaluation.html#Reason"},{"doc":"openfeature/evaluation","title":"ResolutionDetails","content":"pub type ResolutionDetails(value) {\n  ResolutionSuccess(value: value, reason: Reason)\n  ResolutionError(\n    value: value,\n    reason: Reason,\n    code: ErrorCode,\n    message: String,\n  )\n}\n\nResolutionSuccess(value: value, reason: Reason)\n\n\nResolutionError(\n  value: value,\n  reason: Reason,\n  code: ErrorCode,\n  message: String,\n)\n\n\nSynonyms:\nopenfeature/evaluation.ResolutionDetails\nopenfeature/evaluation ResolutionDetails","url":"openfeature/evaluation.html#ResolutionDetails"},{"doc":"openfeature/evaluation","title":"StringEvaluation","content":"pub type StringEvaluation =\n  GenericEvaluation(String)\n\n\nSynonyms:\nopenfeature/evaluation.StringEvaluation\nopenfeature/evaluation StringEvaluation","url":"openfeature/evaluation.html#StringEvaluation"},{"doc":"openfeature/evaluation","title":"openfeature/evaluation","content":"","url":"openfeature/evaluation.html"},{"doc":"openfeature/provider","title":"FeatureProvider","content":"pub type FeatureProvider {\n  FeatureProvider(\n    initialize: fn(EvaluationContext) -&gt; Result(Nil, Nil),\n    shutdown: fn() -&gt; Nil,\n    get_metadata: fn() -&gt; Metadata,\n    resolve_bool_evaluation: BoolEvaluation,\n    resolve_string_evaluation: StringEvaluation,\n    resolve_int_evaluation: IntEvaluation,\n    resolve_float_evaluation: FloatEvaluation,\n    resolve_dynamic_evaluation: DynamicEvaluation,\n  )\n}\n\nFeatureProvider(\n  initialize: fn(EvaluationContext) -&gt; Result(Nil, Nil),\n  shutdown: fn() -&gt; Nil,\n  get_metadata: fn() -&gt; Metadata,\n  resolve_bool_evaluation: BoolEvaluation,\n  resolve_string_evaluation: StringEvaluation,\n  resolve_int_evaluation: IntEvaluation,\n  resolve_float_evaluation: FloatEvaluation,\n  resolve_dynamic_evaluation: DynamicEvaluation,\n)\n\n\nSynonyms:\nopenfeature/provider.FeatureProvider\nopenfeature/provider FeatureProvider","url":"openfeature/provider.html#FeatureProvider"},{"doc":"openfeature/provider","title":"Metadata","content":"pub type Metadata {\n  Metadata(name: String)\n}\n\nMetadata(name: String)\n\n\nSynonyms:\nopenfeature/provider.Metadata\nopenfeature/provider Metadata","url":"openfeature/provider.html#Metadata"},{"doc":"openfeature/provider","title":"openfeature/provider","content":"","url":"openfeature/provider.html"},{"doc":"openfeature/client","title":"Client","content":"pub type Client {\n  Client(\n    provider: FeatureProvider,\n    metadata: ClientMetadata,\n    evaluation_context: EvaluationContext,\n  )\n}\n\nClient(\n  provider: FeatureProvider,\n  metadata: ClientMetadata,\n  evaluation_context: EvaluationContext,\n)\n\n\nSynonyms:\nopenfeature/client.Client\nopenfeature/client Client","url":"openfeature/client.html#Client"},{"doc":"openfeature/client","title":"ClientMetadata","content":"pub type ClientMetadata {\n  ClientMetadata(domain: Domain)\n}\n\nClientMetadata(domain: Domain)\n\n\nSynonyms:\nopenfeature/client.ClientMetadata\nopenfeature/client ClientMetadata","url":"openfeature/client.html#ClientMetadata"},{"doc":"openfeature/client","title":"get_bool_details","content":"pub fn get_bool_details(\n  client: Client,\n  flag: String,\n  default_value: Bool,\n  evaluation_context: EvaluationContext,\n) -&gt; ResolutionDetails(Bool)\n\nSynonyms:\nopenfeature/client.get_bool_details\nopenfeature/client get_bool_details","url":"openfeature/client.html#get_bool_details"},{"doc":"openfeature/client","title":"get_bool_value","content":"pub fn get_bool_value(\n  client: Client,\n  flag: String,\n  default_value: Bool,\n  evaluation_context: EvaluationContext,\n) -&gt; Bool\n\nSynonyms:\nopenfeature/client.get_bool_value\nopenfeature/client get_bool_value","url":"openfeature/client.html#get_bool_value"},{"doc":"openfeature/client","title":"get_domain","content":"pub fn get_domain(metadata: ClientMetadata) -&gt; Domain\n\nSynonyms:\nopenfeature/client.get_domain\nopenfeature/client get_domain","url":"openfeature/client.html#get_domain"},{"doc":"openfeature/client","title":"get_dynamic_details","content":"pub fn get_dynamic_details(\n  client: Client,\n  flag: String,\n  default_value: Dynamic,\n  evaluation_context: EvaluationContext,\n) -&gt; ResolutionDetails(Dynamic)\n\nSynonyms:\nopenfeature/client.get_dynamic_details\nopenfeature/client get_dynamic_details","url":"openfeature/client.html#get_dynamic_details"},{"doc":"openfeature/client","title":"get_dynamic_value","content":"pub fn get_dynamic_value(\n  client: Client,\n  flag: String,\n  default_value: Dynamic,\n  evaluation_context: EvaluationContext,\n) -&gt; Dynamic\n\nSynonyms:\nopenfeature/client.get_dynamic_value\nopenfeature/client get_dynamic_value","url":"openfeature/client.html#get_dynamic_value"},{"doc":"openfeature/client","title":"get_float_details","content":"pub fn get_float_details(\n  client: Client,\n  flag: String,\n  default_value: Float,\n  evaluation_context: EvaluationContext,\n) -&gt; ResolutionDetails(Float)\n\nSynonyms:\nopenfeature/client.get_float_details\nopenfeature/client get_float_details","url":"openfeature/client.html#get_float_details"},{"doc":"openfeature/client","title":"get_float_value","content":"pub fn get_float_value(\n  client: Client,\n  flag: String,\n  default_value: Float,\n  evaluation_context: EvaluationContext,\n) -&gt; Float\n\nSynonyms:\nopenfeature/client.get_float_value\nopenfeature/client get_float_value","url":"openfeature/client.html#get_float_value"},{"doc":"openfeature/client","title":"get_int_details","content":"pub fn get_int_details(\n  client: Client,\n  flag: String,\n  default_value: Int,\n  evaluation_context: EvaluationContext,\n) -&gt; ResolutionDetails(Int)\n\nSynonyms:\nopenfeature/client.get_int_details\nopenfeature/client get_int_details","url":"openfeature/client.html#get_int_details"},{"doc":"openfeature/client","title":"get_int_value","content":"pub fn get_int_value(\n  client: Client,\n  flag: String,\n  default_value: Int,\n  evaluation_context: EvaluationContext,\n) -&gt; Int\n\nSynonyms:\nopenfeature/client.get_int_value\nopenfeature/client get_int_value","url":"openfeature/client.html#get_int_value"},{"doc":"openfeature/client","title":"get_name","content":"pub fn get_name(metadata: ClientMetadata) -&gt; Domain\n\nSynonyms:\nopenfeature/client.get_name\nopenfeature/client get_name","url":"openfeature/client.html#get_name"},{"doc":"openfeature/client","title":"get_string_details","content":"pub fn get_string_details(\n  client: Client,\n  flag: String,\n  default_value: String,\n  evaluation_context: EvaluationContext,\n) -&gt; ResolutionDetails(String)\n\nSynonyms:\nopenfeature/client.get_string_details\nopenfeature/client get_string_details","url":"openfeature/client.html#get_string_details"},{"doc":"openfeature/client","title":"get_string_value","content":"pub fn get_string_value(\n  client: Client,\n  flag: String,\n  default_value: String,\n  evaluation_context: EvaluationContext,\n) -&gt; String\n\nSynonyms:\nopenfeature/client.get_string_value\nopenfeature/client get_string_value","url":"openfeature/client.html#get_string_value"},{"doc":"openfeature/client","title":"set_context","content":"pub fn set_context(\n  client: Client,\n  evaluation_context: EvaluationContext,\n) -&gt; Client\n\nSynonyms:\nopenfeature/client.set_context\nopenfeature/client set_context","url":"openfeature/client.html#set_context"},{"doc":"openfeature/client","title":"openfeature/client","content":"","url":"openfeature/client.html"},{"doc":"openfeature/providers/no_op","title":"provider","content":"pub fn provider() -&gt; FeatureProvider\n\nSynonyms:\nopenfeature/providers/no_op.provider\nopenfeature/providers/no_op provider","url":"openfeature/providers/no_op.html#provider"},{"doc":"openfeature/providers/no_op","title":"openfeature/providers/no_op","content":"","url":"openfeature/providers/no_op.html"},{"doc":"openfeature/api","title":"get_client","content":"pub fn get_client() -&gt; Client\n\nSynonyms:\nopenfeature/api.get_client\nopenfeature/api get_client","url":"openfeature/api.html#get_client"},{"doc":"openfeature/api","title":"get_domain_client","content":"pub fn get_domain_client(domain: String) -&gt; Client\n Initialise and retrieve a new client for the provided domain.\n If the domain has a corresponding provider registered, the client will use that provider.\n Otherwise, the global default provider is used.\nSynonyms:\nopenfeature/api.get_domain_client\nopenfeature/api get_domain_client","url":"openfeature/api.html#get_domain_client"},{"doc":"openfeature/api","title":"get_domain_provider_metadata","content":"pub fn get_domain_provider_metadata(domain: String) -&gt; Metadata\n\nSynonyms:\nopenfeature/api.get_domain_provider_metadata\nopenfeature/api get_domain_provider_metadata","url":"openfeature/api.html#get_domain_provider_metadata"},{"doc":"openfeature/api","title":"get_provider_metadata","content":"pub fn get_provider_metadata() -&gt; Metadata\n\nSynonyms:\nopenfeature/api.get_provider_metadata\nopenfeature/api get_provider_metadata","url":"openfeature/api.html#get_provider_metadata"},{"doc":"openfeature/api","title":"set_context","content":"pub fn set_context(context: EvaluationContext) -&gt; Nil\n\nSynonyms:\nopenfeature/api.set_context\nopenfeature/api set_context","url":"openfeature/api.html#set_context"},{"doc":"openfeature/api","title":"set_domain_provider","content":"pub fn set_domain_provider(\n  domain: String,\n  provider: FeatureProvider,\n) -&gt; Nil\n\nSynonyms:\nopenfeature/api.set_domain_provider\nopenfeature/api set_domain_provider","url":"openfeature/api.html#set_domain_provider"},{"doc":"openfeature/api","title":"set_provider","content":"pub fn set_provider(\n  provider: FeatureProvider,\n) -&gt; Result(Nil, Nil)\n\nSynonyms:\nopenfeature/api.set_provider\nopenfeature/api set_provider","url":"openfeature/api.html#set_provider"},{"doc":"openfeature/api","title":"shutdown","content":"pub fn shutdown() -&gt; Bool\n\nSynonyms:\nopenfeature/api.shutdown\nopenfeature/api shutdown","url":"openfeature/api.html#shutdown"},{"doc":"openfeature/api","title":"openfeature/api","content":"","url":"openfeature/api.html"},{"doc":"openfeature/providers/in_memory","title":"Flag","content":"pub type Flag {\n  Flag(\n    default_variant: String,\n    variants: Variants,\n    context_evaluator: Option(\n      fn(EvaluationContext) -&gt; ResolutionDetails(dynamic.Dynamic),\n    ),\n  )\n}\n\nFlag(\n  default_variant: String,\n  variants: Variants,\n  context_evaluator: Option(\n    fn(EvaluationContext) -&gt; ResolutionDetails(dynamic.Dynamic),\n  ),\n)\n\n\nSynonyms:\nopenfeature/providers/in_memory.Flag\nopenfeature/providers/in_memory Flag","url":"openfeature/providers/in_memory.html#Flag"},{"doc":"openfeature/providers/in_memory","title":"Variants","content":"pub type Variants =\n  Dict(String, dynamic.Dynamic)\n\n\nSynonyms:\nopenfeature/providers/in_memory.Variants\nopenfeature/providers/in_memory Variants","url":"openfeature/providers/in_memory.html#Variants"},{"doc":"openfeature/providers/in_memory","title":"new_variants","content":"pub fn new_variants(\n  variants: List(#(String, a)),\n) -&gt; Dict(String, Dynamic)\n\nSynonyms:\nopenfeature/providers/in_memory.new_variants\nopenfeature/providers/in_memory new_variants","url":"openfeature/providers/in_memory.html#new_variants"},{"doc":"openfeature/providers/in_memory","title":"provider","content":"pub fn provider(from: Dict(String, Flag)) -&gt; FeatureProvider\n\nSynonyms:\nopenfeature/providers/in_memory.provider\nopenfeature/providers/in_memory provider","url":"openfeature/providers/in_memory.html#provider"},{"doc":"openfeature/providers/in_memory","title":"openfeature/providers/in_memory","content":"","url":"openfeature/providers/in_memory.html"}]);